@@ -35,7 +35,8 @@ class Synapse(ABC):
             The route method that looks for the type of the synapse request and invokes
             appropriate synapse supported method.
         """
-        self.logger.info(self.raw_request)
+        self.logger.info(self.request_type)
+        self.logger.info(self.request)
         response = None
         try:
             if self.request_type == RequestType.TEST:
